@@ -16,6 +16,8 @@
  */
 package org.codehaus.plexus.archiver.jar;
 
+import javax.inject.Named;
+
 import static org.codehaus.plexus.archiver.util.Streams.bufferedOutputStream;
 import static org.codehaus.plexus.archiver.util.Streams.fileInputStream;
 import static org.codehaus.plexus.archiver.util.Streams.fileOutputStream;
@@ -27,6 +29,7 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStreamWriter;
 import java.io.PrintWriter;
+import java.nio.charset.StandardCharsets;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.Comparator;
@@ -37,7 +40,6 @@ import java.util.Set;
 import java.util.SortedMap;
 import java.util.StringTokenizer;
 import java.util.TreeMap;
-import java.util.Vector;
 
 import org.apache.commons.compress.archivers.zip.ZipArchiveEntry;
 import org.apache.commons.compress.archivers.zip.ZipArchiveOutputStream;
@@ -46,16 +48,11 @@ import org.apache.commons.compress.parallel.InputStreamSupplier;
 import org.codehaus.plexus.archiver.ArchiverException;
 import org.codehaus.plexus.archiver.zip.ConcurrentJarCreator;
 import org.codehaus.plexus.archiver.zip.ZipArchiver;
-import org.codehaus.plexus.logging.Logger;
-import org.codehaus.plexus.logging.console.ConsoleLogger;
 
 /**
  * Base class for tasks that build archives in JAR file format.
  */
-@SuppressWarnings(
-{
-    "NullableProblems"
-} )
+@Named( "jar" )
 public class JarArchiver
     extends ZipArchiver
 {
@@ -139,12 +136,12 @@ public class JarArchiver
      * <p/>
      * Will not be filled unless the user has asked for an index.
      */
-    private Vector<String> rootEntries;
+    private final List<String> rootEntries;
 
     /**
      * Path containing jars that shall be indexed in addition to this archive.
      */
-    private ArrayList<String> indexJars;
+    private List<String> indexJars;
 
     /**
      * Creates a minimal default manifest with {@code Manifest-Version: 1.0} only.
@@ -159,7 +156,7 @@ public class JarArchiver
         super();
         archiveType = "jar";
         setEncoding( "UTF8" );
-        rootEntries = new Vector<String>();
+        rootEntries = new ArrayList<>();
     }
 
     /**
@@ -299,7 +296,7 @@ public class JarArchiver
     {
         if ( indexJars == null )
         {
-            indexJars = new ArrayList<String>();
+            indexJars = new ArrayList<>();
         }
         indexJars.add( indexJar.getAbsolutePath() );
     }
@@ -373,13 +370,14 @@ public class JarArchiver
         }
 
         zipDir( null, zOut, "META-INF/", DEFAULT_DIR_MODE, getEncoding() );
-        // time to write the manifest
-        ByteArrayOutputStream baos = new ByteArrayOutputStream();
-        manifest.write( baos );
 
-        ByteArrayInputStream bais = new ByteArrayInputStream( baos.toByteArray() );
-        super.zipFile( createInputStreamSupplier( bais ), zOut, MANIFEST_NAME, System.currentTimeMillis(), null,
-                       DEFAULT_FILE_MODE, null, false );
+        // time to write the manifest
+        ByteArrayOutputStream baos = new ByteArrayOutputStream( 128 );
+        manifest.write( baos );
+        InputStreamSupplier in = () -> new ByteArrayInputStream( baos.toByteArray() );
+
+        super.zipFile( in, zOut, MANIFEST_NAME, System.currentTimeMillis(), null, DEFAULT_FILE_MODE, null,
+                       false );
         super.initZipOutputStream( zOut );
     }
 
@@ -408,9 +406,9 @@ public class JarArchiver
     private void createIndexList( ConcurrentJarCreator zOut )
         throws IOException, ArchiverException
     {
-        ByteArrayOutputStream baos = new ByteArrayOutputStream();
+        ByteArrayOutputStream baos = new ByteArrayOutputStream( 128 );
         // encoding must be UTF8 as specified in the specs.
-        PrintWriter writer = new PrintWriter( new OutputStreamWriter( baos, "UTF8" ) );
+        PrintWriter writer = new PrintWriter( new OutputStreamWriter( baos, StandardCharsets.UTF_8 ) );
 
         // version-info blankline
         writer.println( "JarIndex-Version: 1.0" );
@@ -440,7 +438,7 @@ public class JarArchiver
                 filteredDirs.remove( META_INF_NAME + '/' );
             }
         }
-        writeIndexLikeList( new ArrayList<String>( filteredDirs ), rootEntries, writer );
+        writeIndexLikeList( new ArrayList<>( filteredDirs ), rootEntries, writer );
         writer.println();
 
         if ( indexJars != null )
@@ -464,8 +462,8 @@ public class JarArchiver
                 String name = findJarName( indexJar, cpEntries );
                 if ( name != null )
                 {
-                    ArrayList<String> dirs = new ArrayList<String>();
-                    ArrayList<String> files = new ArrayList<String>();
+                    List<String> dirs = new ArrayList<>();
+                    List<String> files = new ArrayList<>();
                     grabFilesAndDirs( indexJar, dirs, files );
                     if ( dirs.size() + files.size() > 0 )
                     {
@@ -479,9 +477,9 @@ public class JarArchiver
 
         writer.flush();
 
-        ByteArrayInputStream bais = new ByteArrayInputStream( baos.toByteArray() );
+        InputStreamSupplier in = () -> new ByteArrayInputStream( baos.toByteArray() );
 
-        super.zipFile( createInputStreamSupplier( bais ), zOut, INDEX_NAME, System.currentTimeMillis(), null,
+        super.zipFile( in, zOut, INDEX_NAME, System.currentTimeMillis(), null,
                        DEFAULT_FILE_MODE, null, true );
     }
 
@@ -511,9 +509,9 @@ public class JarArchiver
         }
         else
         {
-            if ( index && ( !vPath.contains( "/" ) ) )
+            if ( index && !vPath.contains( "/" ) )
             {
-                rootEntries.addElement( vPath );
+                rootEntries.add( vPath );
             }
             super.zipFile( is, zOut, vPath, lastModified, fromArchive, mode, symlinkDestination, addInParallel );
         }
@@ -624,7 +622,7 @@ public class JarArchiver
             filesetManifest = null;
             originalManifest = null;
         }
-        rootEntries.removeAllElements();
+        rootEntries.clear();
     }
 
     /**
@@ -722,21 +720,9 @@ public class JarArchiver
             return new File( fileName ).getName();
         }
         fileName = fileName.replace( File.separatorChar, '/' );
-        SortedMap<String, String> matches = new TreeMap<String, String>( new Comparator<String>()
-        {
 
-            // longest match comes first
-            @Override
-            public int compare( String o1, String o2 )
-            {
-                if ( ( o1 != null ) && ( o2 != null ) )
-                {
-                    return o2.length() - o1.length();
-                }
-                return 0;
-            }
-
-        } );
+        // longest match comes first
+        SortedMap<String, String> matches = new TreeMap<>( Comparator.comparingInt( String::length ).reversed() );
 
         for ( String aClasspath : classpath )
         {
@@ -774,26 +760,24 @@ public class JarArchiver
      *
      * @throws java.io.IOException
      */
-    protected static void grabFilesAndDirs( String file, List<String> dirs, List<String> files )
+    private void grabFilesAndDirs( String file, List<String> dirs, List<String> files )
         throws IOException
     {
         File zipFile = new File( file );
         if ( !zipFile.exists() )
         {
-            Logger logger = new ConsoleLogger( Logger.LEVEL_INFO, "console" );
-            logger.error( "JarArchive skipping non-existing file: " + zipFile.getAbsolutePath() );
+            getLogger().error( "JarArchive skipping non-existing file: " + zipFile.getAbsolutePath() );
         }
         else if ( zipFile.isDirectory() )
         {
-            Logger logger = new ConsoleLogger( Logger.LEVEL_INFO, "console" );
-            logger.info( "JarArchiver skipping indexJar " + zipFile + " because it is not a jar" );
+            getLogger().info( "JarArchiver skipping indexJar " + zipFile + " because it is not a jar" );
         }
         else
         {
             try ( ZipFile zf = new ZipFile( file, "utf-8" ) )
             {
                 Enumeration<ZipArchiveEntry> entries = zf.getEntries();
-                HashSet<String> dirSet = new HashSet<String>();
+                HashSet<String> dirSet = new HashSet<>();
                 while ( entries.hasMoreElements() )
                 {
                     ZipArchiveEntry ze = entries.nextElement();
@@ -825,4 +809,22 @@ public class JarArchiver
         }
     }
 
+    /**
+     * Override the behavior of the Zip Archiver to match the output of the JAR tool.
+     *
+     * @param zipEntry to set the last modified time
+     * @param lastModifiedTime to set in the zip entry only if {@link #getLastModifiedTime()} returns null
+     */
+    @Override
+    protected void setZipEntryTime( ZipArchiveEntry zipEntry, long lastModifiedTime )
+    {
+        if ( getLastModifiedTime() != null )
+        {
+            lastModifiedTime = getLastModifiedTime().toMillis();
+        }
+
+        // The JAR tool does not round up, so we keep that behavior here (JDK-8277755).
+        zipEntry.setTime( lastModifiedTime );
+    }
+
 }
