@@ -16,6 +16,8 @@
  */
 package org.codehaus.plexus.archiver.tar;
 
+import javax.inject.Named;
+
 import static org.codehaus.plexus.archiver.util.Streams.bufferedOutputStream;
 
 import java.io.File;
@@ -29,6 +31,7 @@ import org.apache.commons.compress.archivers.tar.TarArchiveEntry;
 import org.apache.commons.compress.archivers.tar.TarArchiveOutputStream;
 import org.apache.commons.compress.compressors.bzip2.BZip2CompressorOutputStream;
 import org.apache.commons.compress.compressors.xz.XZCompressorOutputStream;
+import org.apache.commons.compress.compressors.zstandard.ZstdCompressorOutputStream;
 import org.codehaus.plexus.archiver.AbstractArchiver;
 import org.codehaus.plexus.archiver.ArchiveEntry;
 import org.codehaus.plexus.archiver.ArchiverException;
@@ -46,6 +49,7 @@ import org.iq80.snappy.SnappyOutputStream;
 /**
  * @author <a href="mailto:evenisse@codehaus.org">Emmanuel Venisse</a>
  */
+@Named( "tar" )
 public class TarArchiver
     extends AbstractArchiver
 {
@@ -59,7 +63,7 @@ public class TarArchiver
 
     private TarCompressionMethod compression = TarCompressionMethod.none;
 
-    private TarOptions options = new TarOptions();
+    private final TarOptions options = new TarOptions();
 
     private TarArchiveOutputStream tOut;
 
@@ -283,7 +287,7 @@ public class TarArchiver
                 te = new TarArchiveEntry( vPath );
             }
 
-            if ( getLastModifiedDate() == null )
+            if ( getLastModifiedTime() == null )
             {
                 long teLastModified = entry.getResource().getLastModified();
                 te.setModTime( teLastModified == PlexusIoResource.UNKNOWN_MODIFICATION_DATE
@@ -292,7 +296,7 @@ public class TarArchiver
             }
             else
             {
-                te.setModTime( getLastModifiedDate() );
+                te.setModTime( getLastModifiedTime().toMillis() );
             }
 
             if ( entry.getType() == ArchiveEntry.SYMLINK )
@@ -474,14 +478,15 @@ public class TarArchiver
     /**
      * Valid Modes for Compression attribute to Tar Task
      */
-    public static enum TarCompressionMethod
+    public enum TarCompressionMethod
     {
 
         none,
         gzip,
         bzip2,
         snappy,
-        xz
+        xz,
+        zstd
 
     }
 
@@ -504,6 +509,10 @@ public class TarArchiver
         {
             return new XZCompressorOutputStream( bufferedOutputStream( ostream ) );
         }
+        else if ( TarCompressionMethod.zstd.equals( tarCompressionMethod ) )
+        {
+            return new ZstdCompressorOutputStream( bufferedOutputStream( ostream ) );
+        }
 
         return ostream;
     }
