@@ -16,6 +16,9 @@
  */
 package org.codehaus.plexus.archiver.zip;
 
+import javax.inject.Named;
+
+@Named( "zip" )
 public class ZipArchiver
     extends AbstractZipArchiver
 {
