@@ -2,17 +2,20 @@ package org.codehaus.plexus.archiver;
 
 import java.io.File;
 import java.io.IOException;
-import junit.framework.TestCase;
 
-public class AbstractArchiverTest extends TestCase
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
+
+import static org.junit.jupiter.api.Assertions.assertEquals;
+
+public class AbstractArchiverTest
 {
 
     private AbstractArchiver archiver;
 
-    @Override
-    protected void setUp() throws Exception
+    @BeforeEach
+    public void setUp() throws Exception
     {
-        super.setUp();
         this.archiver = new AbstractArchiver()
         {
 
@@ -37,6 +40,7 @@ public class AbstractArchiverTest extends TestCase
         };
     }
 
+    @Test
     public void testModesAndOverridesAreUnsetByDefault()
     {
         assertEquals( -1, archiver.getDefaultFileMode() );
@@ -46,12 +50,14 @@ public class AbstractArchiverTest extends TestCase
         assertEquals( -1, archiver.getOverrideDirectoryMode() );
     }
 
+    @Test
     public void testWhenUnsetModeUsesDefault()
     {
         assertEquals( Archiver.DEFAULT_FILE_MODE, archiver.getFileMode() );
         assertEquals( Archiver.DEFAULT_DIR_MODE, archiver.getDirectoryMode() );
     }
 
+    @Test
     public void testSetModeIsUsedWithFlagsForType()
     {
         archiver.setFileMode( 0400 );
@@ -61,6 +67,7 @@ public class AbstractArchiverTest extends TestCase
         assertEquals( 040600, archiver.getDirectoryMode() );
     }
 
+    @Test
     public void testSetDefaultIncludesFlagsForType()
     {
         archiver.setDefaultFileMode( 0400 );
@@ -70,6 +77,7 @@ public class AbstractArchiverTest extends TestCase
         assertEquals( 040600, archiver.getDefaultDirectoryMode() );
     }
 
+    @Test
     public void testDefaultIsUsedWhenModeIsUnset()
     {
         archiver.setDefaultFileMode( 0400 );
@@ -79,6 +87,7 @@ public class AbstractArchiverTest extends TestCase
         assertEquals( 040600, archiver.getDirectoryMode() );
     }
 
+    @Test
     public void testOverridesCanBeReset()
     {
         archiver.setFileMode( 0400 );
@@ -90,6 +99,7 @@ public class AbstractArchiverTest extends TestCase
         assertEquals( -1, archiver.getOverrideDirectoryMode() );
     }
 
+    @Test
     public void testSetDestFileInTheWorkingDir() {
         archiver.setDestFile( new File( "archive" ) );
     }
