@@ -36,6 +36,12 @@ import org.codehaus.plexus.archiver.exceptions.EmptyArchiveException;
 import org.codehaus.plexus.archiver.zip.ZipArchiver;
 import org.codehaus.plexus.util.FileUtils;
 import org.codehaus.plexus.util.IOUtil;
+import org.junit.jupiter.api.Test;
+
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNotEquals;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assertions.fail;
 
 /**
  * @author Emmanuel Venisse
@@ -44,14 +50,15 @@ public class GZipArchiverTest
     extends BasePlexusArchiverTest
 {
 
+    @Test
     public void testCreateArchive()
         throws Exception
     {
-        ZipArchiver zipArchiver = (ZipArchiver) lookup( Archiver.ROLE, "zip" );
+        ZipArchiver zipArchiver = (ZipArchiver) lookup( Archiver.class, "zip" );
         zipArchiver.addDirectory( getTestFile( "src" ) );
         zipArchiver.setDestFile( getTestFile( "target/output/archiveForGzip.zip" ) );
         zipArchiver.createArchive();
-        GZipArchiver archiver = (GZipArchiver) lookup( Archiver.ROLE, "gzip" );
+        GZipArchiver archiver = (GZipArchiver) lookup( Archiver.class, "gzip" );
         String[] inputFiles = new String[ 1 ];
         inputFiles[0] = "archiveForGzip.zip";
         archiver.addDirectory( getTestFile( "target/output" ), inputFiles, null );
@@ -59,11 +66,11 @@ public class GZipArchiverTest
         archiver.createArchive();
     }
 
-
+    @Test
     public void testCreateEmptyArchive()
         throws Exception
     {
-        GZipArchiver archiver = (GZipArchiver) lookup( Archiver.ROLE, "gzip" );
+        GZipArchiver archiver = (GZipArchiver) lookup( Archiver.class, "gzip" );
         archiver.setDestFile( getTestFile( "target/output/empty.gz" ) );
         try
         {
@@ -76,19 +83,20 @@ public class GZipArchiverTest
         }
     }
 
+    @Test
     public void testCreateResourceCollection()
         throws Exception
     {
         final File pomFile = new File( "pom.xml" );
         final File gzFile = new File( "target/output/pom.xml.gz" );
-        GZipArchiver gzipArchiver = (GZipArchiver) lookup( Archiver.ROLE, "gzip" );
+        GZipArchiver gzipArchiver = (GZipArchiver) lookup( Archiver.class, "gzip" );
         gzipArchiver.setDestFile( gzFile );
         gzipArchiver.addFile( pomFile, "pom.xml" );
         FileUtils.removePath( gzFile.getPath() );
         gzipArchiver.createArchive();
 
         final File zipFile = new File( "target/output/pom.zip" );
-        ZipArchiver zipArchiver = (ZipArchiver) lookup( Archiver.ROLE, "zip" );
+        ZipArchiver zipArchiver = (ZipArchiver) lookup( Archiver.class, "zip" );
         zipArchiver.setDestFile( zipFile );
         zipArchiver.addArchivedFileSet( gzFile, "prfx/" );
         FileUtils.removePath( zipFile.getPath() );
@@ -110,6 +118,7 @@ public class GZipArchiverTest
      *
      * @throws Exception
      */
+    @Test
     public void testTarGzIsForcedBehaviour() throws Exception
     {
         GZipArchiver gZipArchiver = (GZipArchiver) createArchiver( "gzip" );
@@ -128,7 +137,7 @@ public class GZipArchiverTest
 
         final long firstRunTime = gZipArchiver.getDestFile().lastModified();
 
-        assertFalse( creationTime == firstRunTime );
+        assertNotEquals( creationTime, firstRunTime );
 
         gZipArchiver = (GZipArchiver) createArchiver( "gzip" );
 
