@@ -18,19 +18,23 @@ package org.codehaus.plexus.archiver.sar;
 import org.codehaus.plexus.archiver.BasePlexusArchiverTest;
 import org.codehaus.plexus.archiver.manager.ArchiverManager;
 import org.codehaus.plexus.components.io.resources.PlexusIoResourceCollection;
+import org.junit.jupiter.api.Test;
+
+import static org.junit.jupiter.api.Assertions.assertNotNull;
 
 public class SarArchiverTest
     extends BasePlexusArchiverTest
 {
 
+    @Test
     public void testLookup()
         throws Exception
     {
-        ArchiverManager dam = (ArchiverManager) lookup( ArchiverManager.ROLE );
+        ArchiverManager dam = lookup( ArchiverManager.class );
         PlexusIoResourceCollection sar = dam.getResourceCollection( "sar" );
         assertNotNull( sar );
         PlexusIoResourceCollection archiver =
-            (PlexusIoResourceCollection) lookup( PlexusIoResourceCollection.ROLE, "sar" );
+            (PlexusIoResourceCollection) lookup( PlexusIoResourceCollection.class, "sar" );
 
         assertNotNull( archiver );
     }
