@@ -1,31 +1,37 @@
 package org.codehaus.plexus.archiver.tar;
 
 import java.io.File;
-import java.io.FileWriter;
 import java.io.IOException;
 import java.io.Writer;
 import java.nio.charset.StandardCharsets;
 import java.nio.file.Files;
 import java.util.ArrayList;
 import java.util.List;
-import org.codehaus.plexus.PlexusTestCase;
 import org.codehaus.plexus.archiver.Archiver;
+import org.codehaus.plexus.archiver.TestSupport;
 import org.codehaus.plexus.archiver.UnArchiver;
 import org.codehaus.plexus.archiver.util.DefaultArchivedFileSet;
 import org.codehaus.plexus.components.io.attributes.AttributeUtils;
 import org.codehaus.plexus.components.io.attributes.PlexusIoResourceAttributeUtils;
 import org.codehaus.plexus.components.io.attributes.PlexusIoResourceAttributes;
 import org.codehaus.plexus.util.FileUtils;
-import org.codehaus.plexus.util.Os;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.condition.DisabledOnOs;
+import org.junit.jupiter.api.condition.OS;
+
+import static org.junit.jupiter.api.Assertions.assertEquals;
 
 @SuppressWarnings( "ResultOfMethodCallIgnored" )
 public class TarFileAttributesTest
-    extends PlexusTestCase
+        extends TestSupport
 {
 
     private final List<File> toDelete = new ArrayList<File>();
 
     @Override
+    @BeforeEach
     public void setUp()
         throws Exception
     {
@@ -37,6 +43,7 @@ public class TarFileAttributesTest
     }
 
     @Override
+    @AfterEach
     public void tearDown()
         throws Exception
     {
@@ -73,15 +80,12 @@ public class TarFileAttributesTest
         System.out.println( "\n\nRunning: " + e.getMethodName() + "\n\n" );
     }
 
+    @Test
+    @DisabledOnOs( OS.WINDOWS )
     public void testUseAttributesFromTarArchiveInputInTarArchiverOutput()
         throws Exception
     {
         printTestHeader();
-        if ( checkForWindows() )
-        {
-            System.out.println( "This test cannot run on windows. Aborting." );
-            return;
-        }
 
         File tempFile = File.createTempFile( "tar-file-attributes.", ".tmp" );
         toDelete.add( tempFile );
@@ -118,7 +122,7 @@ public class TarFileAttributesTest
         tarArchiver2.createArchive();
 
         // Cut from here, and feed it into a new tar archiver...then unarchive THAT.
-        TarUnArchiver tarUnArchiver = (TarUnArchiver) lookup( UnArchiver.ROLE, "tar" );
+        TarUnArchiver tarUnArchiver = (TarUnArchiver) lookup( UnArchiver.class, "tar" );
 
         File tempTarDir = File.createTempFile( "tar-test.", ".dir" );
         tempTarDir.delete();
@@ -138,15 +142,12 @@ public class TarFileAttributesTest
 
     }
 
+    @Test
+    @DisabledOnOs( OS.WINDOWS )
     public void testUseDetectedFileAttributes()
         throws Exception
     {
         printTestHeader();
-        if ( checkForWindows() )
-        {
-            System.out.println( "This test cannot run on windows. Aborting." );
-            return;
-        }
 
         File tempFile = File.createTempFile( "tar-file-attributes.", ".tmp" );
         toDelete.add( tempFile );
@@ -172,7 +173,7 @@ public class TarFileAttributesTest
 
         tarArchiver.createArchive();
 
-        TarUnArchiver tarUnArchiver = (TarUnArchiver) lookup( UnArchiver.ROLE, "tar" );
+        TarUnArchiver tarUnArchiver = (TarUnArchiver) lookup( UnArchiver.class, "tar" );
 
         File tempTarDir = File.createTempFile( "tar-test.", ".dir" );
         tempTarDir.delete();
@@ -191,22 +192,13 @@ public class TarFileAttributesTest
 
     }
 
-    private boolean checkForWindows()
-    {
-        return Os.isFamily( Os.FAMILY_WINDOWS );
-    }
-
+    @Test
+    @DisabledOnOs( OS.WINDOWS )
     public void testOverrideDetectedFileAttributes()
         throws Exception
     {
         printTestHeader();
 
-        if ( checkForWindows() )
-        {
-            System.out.println( "This test cannot run on windows. Aborting." );
-            return;
-        }
-
         File tempFile = File.createTempFile( "tar-file-attributes.", ".tmp" );
         toDelete.add( tempFile );
 
@@ -227,7 +219,7 @@ public class TarFileAttributesTest
 
         tarArchiver.createArchive();
 
-        TarUnArchiver tarUnArchiver = (TarUnArchiver) lookup( UnArchiver.ROLE, "tar" );
+        TarUnArchiver tarUnArchiver = (TarUnArchiver) lookup( UnArchiver.class, "tar" );
 
         File tempTarDir = File.createTempFile( "tar-test.", ".dir" );
         tempTarDir.delete();
@@ -249,21 +241,17 @@ public class TarFileAttributesTest
 
     private TarArchiver getPosixCompliantTarArchiver() throws Exception
     {
-        TarArchiver tarArchiver = (TarArchiver) lookup( Archiver.ROLE, "tar" );
+        TarArchiver tarArchiver = (TarArchiver) lookup( Archiver.class, "tar" );
         tarArchiver.setLongfile( TarLongFileMode.posix );
         return tarArchiver;
     }
 
+    @Test
+    @DisabledOnOs( OS.WINDOWS )
     public void testOverrideDetectedFileAttributesUsingFileMode()
         throws Exception
     {
         printTestHeader();
-        if ( checkForWindows() )
-        {
-            System.out.println( "This test cannot run on windows. Aborting." );
-            return;
-        }
-
         File tempFile = File.createTempFile( "tar-file-attributes.", ".tmp" );
         toDelete.add( tempFile );
 
@@ -285,7 +273,7 @@ public class TarFileAttributesTest
 
         tarArchiver.createArchive();
 
-        TarUnArchiver tarUnArchiver = (TarUnArchiver) lookup( UnArchiver.ROLE, "tar" );
+        TarUnArchiver tarUnArchiver = (TarUnArchiver) lookup( UnArchiver.class, "tar" );
 
         File tempTarDir = File.createTempFile( "tar-test.", ".dir" );
         tempTarDir.delete();
